@@ -1,4 +1,5 @@
 import anndata as ad
+import numpy as np
 import pytest
 
 from annsel.datasets import leukemic_bone_marrow_dataset
@@ -7,3 +8,8 @@ from annsel.datasets import leukemic_bone_marrow_dataset
 @pytest.fixture
 def lbm_dataset() -> ad.AnnData:
     return leukemic_bone_marrow_dataset()
+
+
+@pytest.fixture
+def rng() -> np.random.Generator:
+    return np.random.default_rng(42)
